@@ -1,18 +1,17 @@
 from enum import Enum
 from pathlib import Path
 
-from bilibili_api.video import VideoCodecs, VideoQuality
-from nonebot import get_driver, get_plugin_config, require
+from nonebot import require, get_driver, get_plugin_config
+from pilmoji import EmojiStyle
 from pydantic import BaseModel
+from bilibili_api.video import VideoCodecs, VideoQuality
 
 from .constants import PlatformEnum
 
-_nickname: str = next(iter(get_driver().config.nickname), "")
-"""全局名称"""
-
 require("nonebot_plugin_localstore")
 import nonebot_plugin_localstore as _store
 
+_nickname: str = next(iter(get_driver().config.nickname), "")
 _cache_dir: Path = _store.get_plugin_cache_dir()
 _config_dir: Path = _store.get_plugin_config_dir()
 _data_dir: Path = _store.get_plugin_data_dir()
@@ -57,10 +56,12 @@ class Config(BaseModel):
     """自定义字体"""
     parser_need_forward_contents: bool = True
     """是否需要转发媒体内容"""
+    parser_emoji_style: EmojiStyle = EmojiStyle.FACEBOOK
+    """Pilmoji 表情样式"""
 
     @property
     def nickname(self) -> str:
-        """全局名称"""
+        """机器人昵称"""
         return _nickname
 
     @property
@@ -148,6 +149,11 @@ class Config(BaseModel):
         """是否需要转发媒体内容"""
         return self.parser_need_forward_contents
 
+    @property
+    def emoji_style(self) -> EmojiStyle:
+        """Pilmoji 表情样式"""
+        return self.parser_emoji_style
+
 
 pconfig: Config = get_plugin_config(Config)
 """配置"""
