@@ -2,16 +2,15 @@ import asyncio
 from pathlib import Path
 
 import aiofiles
-import httpx
+from httpx import HTTPError, AsyncClient
 from nonebot import logger
 from tqdm.asyncio import tqdm
 
+from .task import auto_task
+from ..utils import merge_av, safe_unlink, generate_file_name
 from ..config import pconfig
 from ..constants import COMMON_HEADER, DOWNLOAD_TIMEOUT
-from ..exception import DownloadException, SizeLimitException, ZeroSizeException
-from ..utils import generate_file_name, merge_av, safe_unlink
-from .task import auto_task
-from .ytdlp import YtdlpDownloader
+from ..exception import DownloadException, ZeroSizeException, SizeLimitException
 
 
 class StreamDownloader:
@@ -20,10 +19,7 @@ class StreamDownloader:
     def __init__(self):
         self.headers: dict[str, str] = COMMON_HEADER.copy()
         self.cache_dir: Path = pconfig.cache_dir
-        self.client: httpx.AsyncClient = httpx.AsyncClient(
-            timeout=DOWNLOAD_TIMEOUT,
-            verify=False,
-        )
+        self.client: AsyncClient = AsyncClient(timeout=DOWNLOAD_TIMEOUT, verify=False)
 
     @auto_task
     async def streamd(
@@ -37,8 +33,8 @@ class StreamDownloader:
 
         Args:
             url (str): url address
-            file_name (str | None, optional): file name. Defaults to get name by parse_url_resource_name.
-            ext_headers (dict[str, str] | None, optional): ext headers. Defaults to None.
+            file_name (str | None): file name. Defaults to generate_file_name.
+            ext_headers (dict[str, str] | None): ext headers. Defaults to None.
 
         Returns:
             Path: file path
@@ -67,7 +63,7 @@ class StreamDownloader:
                     raise ZeroSizeException
 
                 if (file_size := content_length / 1024 / 1024) > pconfig.max_size:
-                    logger.warning(f"媒体 url: {url} 大小 {file_size:.2f} MB 超过 {pconfig.max_size} MB, 取消下载")
+                    logger.warning(f"媒体 url: {url} 大小 {file_size:.2f} MB 超过 {{pconfig.max_size}} MB, 取消下载")
                     raise SizeLimitException
 
                 with self.get_progress_bar(file_name, content_length) as bar:
@@ -76,7 +72,7 @@ class StreamDownloader:
                             await file.write(chunk)
                             bar.update(len(chunk))
 
-        except httpx.HTTPError:
+        except HTTPError:
             await safe_unlink(file_path)
             logger.exception(f"下载失败 | url: {url}, file_path: {file_path}")
             raise DownloadException("媒体下载失败")
@@ -88,7 +84,7 @@ class StreamDownloader:
 
         Args:
             desc (str): 描述
-            total (int | None, optional): 总大小. Defaults to None.
+            total (int | None): 总大小. Defaults to None.
 
         Returns:
             tqdm: 进度条
@@ -115,8 +111,8 @@ class StreamDownloader:
 
         Args:
             url (str): url address
-            video_name (str | None, optional): video name. Defaults to get name by parse url.
-            ext_headers (dict[str, str] | None, optional): ext headers. Defaults to None.
+            video_name (str | None): video name. Defaults to get name by parse url.
+            ext_headers (dict[str, str] | None): ext headers. Defaults to None.
 
         Returns:
             Path: video file path
@@ -140,8 +136,8 @@ class StreamDownloader:
 
         Args:
             url (str): url address
-            audio_name (str | None, optional): audio name. Defaults to get name by parse_url_resource_name.
-            ext_headers (dict[str, str] | None, optional): ext headers. Defaults to None.
+            audio_name (str | None ): audio name. Defaults to generate from url.
+            ext_headers (dict[str, str] | None): ext headers. Defaults to None.
 
         Returns:
             Path: audio file path
@@ -165,8 +161,8 @@ class StreamDownloader:
 
         Args:
             url (str): url
-            img_name (str, optional): image name. Defaults to None.
-            ext_headers (dict[str, str], optional): ext headers. Defaults to None.
+            img_name (str | None): image name. Defaults to generate from url.
+            ext_headers (dict[str, str] | None): ext headers. Defaults to None.
 
         Returns:
             Path: image file path
@@ -188,13 +184,14 @@ class StreamDownloader:
 
         Args:
             urls (list[str]): urls
-            ext_headers (dict[str, str] | None, optional): ext headers. Defaults to None.
+            ext_headers (dict[str, str] | None): ext headers. Defaults to None.
 
         Returns:
             list[Path]: image file paths
         """
         paths_or_errs = await asyncio.gather(
-            *[self.download_img(url, ext_headers=ext_headers) for url in urls], return_exceptions=True
+            *[self.download_img(url, ext_headers=ext_headers) for url in urls],
+            return_exceptions=True,
         )
         return [p for p in paths_or_errs if isinstance(p, Path)]
 
@@ -217,4 +214,12 @@ class StreamDownloader:
 
 
 DOWNLOADER: StreamDownloader = StreamDownloader()
-YTDLP_DOWNLOADER: YtdlpDownloader = YtdlpDownloader()
+
+try:
+    import yt_dlp as yt_dlp
+
+    from .ytdlp import YtdlpDownloader
+
+    YTDLP_DOWNLOADER = YtdlpDownloader()
+except ImportError:
+    YTDLP_DOWNLOADER = None
